--
-- Measure Helper
--
-- @author  	V!rus(Lukas Reiche)
-- @version 	v1
-- @date  	05/02/13
-- @author  	kenny456 (conversion to FS19)
-- @version 	v1.1
-- @date  	20/12/2018
--
--v1.1 - convert to FS19
--	   - switching between metric and imperial unit 

--
-- This mod helps to measure the distance between a point and the Player ingame.
--
-- If you want to learn from this code, go for it. This is why its commented.
--
-- !! If you want to reuse or modify this code, please ask for permission !!
--	Just send a short mail to somersault[at]ich-habe-fertig.com
--


--
-- Measure
--
Measure = {
    active = nil,
}


--
-- Measure.prerequisitesPresent
--
function Measure.prerequisitesPresent(specializations)
    return true;
end


--
-- Measure:loadMap
--
function Measure:loadMap(name)
    -- Only initialize when map is loaded
    if (Measure.active == nil) then
        Measure.active = false;
    end;
	Measure.unitMetric = true
end

;

--
-- Measure:deleteMap
--
function Measure:deleteMap()
end

--
--  Measure:mouseEvent
--
function Measure:mouseEvent(posX, posY, isDown, isUp, button)
    -- (de)activation
    if isDown and button == 3 and Input.isKeyPressed(Input.KEY_lalt) then
        if(not Measure.active) then
            -- player in vehicle?
            local p = nil;
            if g_currentMission.player ~= nil then
                p = g_currentMission.player.rootNode;
            end;
       	    if g_currentMission.controlledVehicle ~= nil then
       	        p = g_currentMission.controlledVehicle.rootNode;
            end;
            -- player exists?
            if p ~= nil then
	        -- get player cords
                aX1, aY1, aZ1 = getWorldTranslation(p);
                Measure.active = true;
            else
                -- not possible to find player position
                print("Not a player and not in vehicle!? => MeasureHelp will not be activated");
            end;
        else
            -- was active, now deactivate
            Measure.active = false;
        end;
    end;
		if isDown and button == 2 then
			if Measure.active then
				--print('unit - '..tostring(Measure.unitMetric))
				Measure.unitMetric = not Measure.unitMetric
			end
		end
end

--
-- Measure:keyEvent
--
function Measure:keyEvent(unicode, sym, modifier, isDown)
end


--
-- Measure:update
--
function Measure:update(dt)

    -- active?
    if Measure.active then

        -- player in vehicle?
	local p = nil;
        if g_currentMission.player ~= nil then
            p = g_currentMission.player.rootNode;
        end;
        if g_currentMission.controlledVehicle ~= nil then
            p = g_currentMission.controlledVehicle.rootNode;
        end;

        -- player exists?
        if p ~= nil then
            -- get playerCords and calculate the distance
            local bX, bY, bZ = getWorldTranslation(p);
            local c2 = ( math.pow( (aX1 - bX), 2 ) + math.pow( (aZ1 - bZ), 2 ) );
	    distance = math.sqrt( ( c2 + math.abs( (aY1 - bY), 2 ) ) );
			if Measure.unitMetric == false then
				distance = distance * 3.28
			end
			distance = math.floor(distance * 100 + 0.5) / 100;
        else
            Measure.active = false;
            print("Not a player and not in vehicle!? => MeasureHelp set active to false");
        end;

    end;
end

--
-- Measure:draw
--

function Measure:draw()
    if Measure.active then

        -- draw the lines
        drawDebugLine(aX1, aY1 - 1, aZ1, 0, 0, 0, aX1, aY1 + 2, aZ1, 0, 0, 0);
        drawDebugLine(aX1-0.1, aY1, aZ1, 1, 0, 0, aX1+0.1, aY1, aZ1, 1, 0, 0);
        drawDebugLine(aX1, aY1, aZ1-0.1, 1, 0, 0, aX1, aY1, aZ1+0.1, 1, 0, 0);

        -- draw the text
        setTextColor(0.98, 0.84, 0, 1);   
        setTextBold(true);
        setTextAlignment(RenderText.ALIGN_CENTER);
		if Measure.unitMetric == false then
			renderText(0.5, 0.1, 0.05, distance .. " ft");
		else
			renderText(0.5, 0.1, 0.05, distance .. " m");
		end
    end;
end
--
-- Register Mod Events
--

addModEventListener(Measure);